package
Version:
v0.0.0-...-57a5977
Opens a new window with list of versions in this module.
Published: Dec 22, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Actor struct {
ID string
}
Actor is an struct that uses a string as the ID.
This ID is used a FlipperID.
FlipperID returns the actor ID.
It satisfies the actor.Actor interface.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.