Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Driver ¶
type Driver struct {
// contains filtered or unexported fields
}
Driver is a store driver that keeps features and gates in memory.
func (*Driver) Configure ¶
Configure configures the memory driver. This driver doesn't have any configuration, so this is a NOOP.
Click to show internal directories.
Click to hide internal directories.